.. :changelog:

History
-------

1.14 (2017-03-30)
+++++++++++++++++

* Updated default behaviour of the `get_header` handler in `TusMiddleware`.

1.13 (2017-03-30)
+++++++++++++++++

* Implemented handler for retrieving request headers in `TusMiddleware`.

1.12 (2017-03-10)
+++++++++++++++++

* Updated `validate_chunk` signature

1.11 (2017-03-10)
+++++++++++++++++

* Implemented `validate_chunk` handler method in TusPatchMixin
* Implemented `validate_success_headers` handler method in TusCreateMixin

1.10 (2017-03-09)
+++++++++++++++++

* Disabled chunk writing to disk

1.9 (2017-03-09)
++++++++++++++++

* Introduced TusUploadStreamParser

1.8 (2017-03-09)
++++++++++++++++

* Introduced setting to include serializer data in respons body

1.7 (2017-03-09)
++++++++++++++++

* Bugfixes

1.6 (2017-03-09)
++++++++++++++++

* Bugfixes

1.5 (2017-03-09)
++++++++++++++++

* Updated middleware, removed required header (bug!)

1.4 (2017-03-09)
++++++++++++++++

* Initial migration

1.3 (2017-03-09)
++++++++++++++++

* Renamed some parameters / classes

1.2 (2017-03-09)
++++++++++++++++

* Cleanup repository.


1.1 (2017-03-09)
++++++++++++++++

* First release on PyPI.
